@@ -10,7 +10,7 @@ def SampleCurves(sample, N=500):
     assert( N >= 2 )
     SUM = Curve([(0,0), (1,1)])
     AREA = []
-    for i in xrange(samples):
+    for i in xrange(sample):
         C = F(S.sweep_threshold_random())
         SUM += C
         AREA.append(C.area())
